# Generated by Django 3.2.13 on 2022-05-02 20:16

from django.db import migrations, models
import django.db.models.deletion
import pretalx_hitalx.models


class Migration(migrations.Migration):

    dependencies = [
        ('event', '0029_event_domain'),
        ('person', '0025_drop_unused_speakerinformation_fields'),
        ('pretalx_hitalx', '0002_auto_20220427_0849'),
    ]

    operations = [
        migrations.CreateModel(
            name='Tour',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False)),
                ('description', models.TextField()),
                ('departure_time', models.DateTimeField()),
                ('start_location', models.TextField()),
                ('type', models.TextField(choices=[(pretalx_hitalx.models.TourType['SHUTTLE'], 'Shuttle'), (pretalx_hitalx.models.TourType['BASSLINER'], 'Bassliner')])),
                ('event', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='event.event')),
                ('passengers', models.ManyToManyField(related_name='tours', to='person.SpeakerProfile')),
            ],
        ),
    ]
